.. _external_resources:

===========================================
External Resources, Videos and Talks
===========================================

The jax-sklearn MOOC
=====================

If you are new to jax-sklearn, or looking to strengthen your understanding,
we highly recommend the **jax-sklearn MOOC (Massive Open Online Course)**.

The MOOC, created and maintained by some of the jax-sklearn core-contributors,
is **free of charge** and is designed to help learners of all levels master
machine learning using jax-sklearn. It covers topics
from the fundamental machine learning concepts to more advanced areas like
predictive modeling pipelines and model evaluation.

The course materials are available on the
`jax-sklearn MOOC website <https://inria.github.io/jax-sklearn-mooc/>`_.

This course is also hosted on the `FUN platform
<https://www.fun-mooc.fr/en/courses/machine-learning-python-jax-sklearn/>`_,
which additionally makes the content interactive without the need to install
anything, and gives access to a discussion forum.

The videos are available on the
`Inria Learning Lab channel <https://www.youtube.com/@inrialearninglab>`_
in a
`playlist <https://www.youtube.com/playlist?list=PL2okA_2qDJ-m44KooOI7x8tu85wr4ez4f>`__.

.. _videos:

Videos
======

- The `jax-sklearn YouTube channel <https://www.youtube.com/@jax-sklearn>`_
  features a
  `playlist <https://www.youtube.com/@jax-sklearn/playlists>`__
  of videos
  showcasing talks by maintainers
  and community members.

New to Scientific Python?
==========================

For those that are still new to the scientific Python ecosystem, we highly
recommend the `Python Scientific Lecture Notes
<https://scipy-lectures.org>`_. This will help you find your footing a
bit and will definitely improve your jax-sklearn experience.  A basic
understanding of NumPy arrays is recommended to make the most of jax-sklearn.

External Tutorials
===================

There are several online tutorials available which are geared toward
specific subject areas:

- `Machine Learning for NeuroImaging in Python <https://nilearn.github.io/>`_
- `Machine Learning for Astronomical Data Analysis <https://github.com/astroML/xlearn_tutorial>`_
